package pr_x.driver.text;



import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.sql.*;

/**  TextConnection provides
 */
public class TextConnection implements Connection {
    // file name
    private String fname;
    // stream connected to file fname
    private BufferedReader bfr;
    // type map
    private Map typeMap = new HashMap();

/**  Constructor */
    TextConnection(String fname) {
	    this.fname = fname;
	    try {bfr=new BufferedReader(new FileReader(fname));}
	    catch (IOException e) {e.printStackTrace();}
    }
/**
 * @return buffered reader
 */
    BufferedReader getBufferedReader() { return bfr; }
/** not supported */
    public PreparedStatement prepareStatement(String sql) throws SQLException {
	    return prepareStatement(sql, ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_READ_ONLY);
    }
/** not supported */
    public CallableStatement prepareCall(String sql) throws SQLException {
	    return prepareCall(sql, ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_READ_ONLY);
    }

/** just return a parameter */
    public String nativeSQL(String sql) throws SQLException { return sql; }
/** autoCommit must be always true */
    public void setAutoCommit(boolean autoCommit) throws SQLException {
      if (!autoCommit) {
	       throw new SQLException("TextDriver: autoCommit must be false");
     	}
    }
/** always true */
    public boolean getAutoCommit() throws SQLException { return true; }
/** transactions are not supported */
    public void commit() throws SQLException {
	    throw new SQLException("TextDriver: commit is not supported");
    }
    public void rollback() throws SQLException {
	     throw new SQLException("TextDriver: rollback is not supported");
    }
/** close Connection */
    public void close() throws SQLException {
	    try {bfr.close();} catch(IOException e) {}
	    bfr = null;
    }
    public boolean isClosed() throws SQLException { return bfr == null; }
/** not supported */
    public DatabaseMetaData getMetaData() throws SQLException { return null; }

    // readOnly must be true
    public void setReadOnly(boolean readOnly) throws SQLException {
     	if (!readOnly) {
	      throw new SQLException("TextDriver: readOnly must be true");
	    }
    }
    public boolean isReadOnly() throws SQLException { return true; }

    // ignore
    public void setCatalog(String catalog) throws SQLException {}
    public String getCatalog() throws SQLException { return fname; }

/** transactions are not supported */
    public void setTransactionIsolation(int level) throws SQLException {}
    public int getTransactionIsolation() throws SQLException {
	     return Connection.TRANSACTION_NONE;
    }

    // no warnings
    public SQLWarning getWarnings() throws SQLException { return null; }
    public void clearWarnings() throws SQLException {}

    /** create a statement */
    public Statement createStatement() throws SQLException {
	    return createStatement(ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_READ_ONLY);
    }
    /** create a statement */
    public Statement createStatement(int resultSetType, int resultSetConcurrency) throws SQLException {
     	return new TextStatement(this, resultSetType, resultSetConcurrency);
    }
/** not supported */
    public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
	     throw new SQLException("TextDriver: PreparedStatement is not supported");
    }
/** not supported */
    public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
     	throw new SQLException("TextDriver: stored procedures are not supported");
    }

    // type map
    public Map getTypeMap() throws SQLException { return typeMap; }
    public void setTypeMap(Map map) throws SQLException { typeMap = map; }
/** standard method */
    public String toString() {
  	 return getClass()+"[file="+fname+"]";
    }
    public PreparedStatement prepareStatement(String sql, String[] colNam) {
      return null;
    }
    public PreparedStatement prepareStatement(String sql, int[] colNam) {
      return null;
    }
    public PreparedStatement prepareStatement(String sql, int colNam, int a, int b) {
      return null;
    }
    public PreparedStatement prepareStatement(String sql, int colNam) {
      return null;
    }

    public CallableStatement prepareCall(String sql, int a, int b, int c ) {
      return null;
    }
    public Statement createStatement(int a, int b, int c) {
      return null;
    }
    public void releaseSavepoint(Savepoint sp) {}
    public void rollback(Savepoint sp) {}
    public Savepoint setSavepoint() {return null;}
    public Savepoint setSavepoint(String sp) {return null;}
    public int getHoldability() {return 0;}
    public int getHoldability(int x) {return 0;}
    public void setHoldability(int x) {}
}