package pr_x.driver.text;

import java.sql.*;

/**
 *
 *  only FETCH_FORWARD is supported
 *
 */
public class TextStatement implements Statement {
    /** connection */
    private TextConnection con;
    /** concurrency */
    private int concurrency;
    /** type */
    private int type;
    /** fetch direction and size */
    private final int fetchDirection = ResultSet.FETCH_FORWARD;
    private int fetchSize;
    /** maximum field size */
    private int maxFieldSize;
    /** maximum number of rows to be fetched */
    private int maxRows;
    /** generated result set */
    private ResultSet rs;

    /** Constructor of basal TextStatement  */
    public TextStatement(TextConnection con, int type, int concurrency) {
	    this.con = con;
	    this.type = type;
	    this.concurrency = concurrency;
    }
    /** Create and return a result set
     *  @param sql selects rows containing the string,
     *               if null selects all.
     *  @return   TextResultSet
     */
    public ResultSet executeQuery(String sql) throws SQLException {
	    return new TextResultSet(this, sql);
    }
    // multiple results are not supported
    public boolean execute(String sql) throws SQLException { return false; }
    public ResultSet getResultSet() throws SQLException { return null; }
    public boolean getMoreResults() throws SQLException { return false; }
    public int getUpdateCount() throws SQLException { return -1; }
    /** Update is not supported */
    public int executeUpdate(String sql) throws SQLException {
	    throw new SQLException("TextStatement: update is not supported");
    }
    // close generated result set
    public void close() throws SQLException { if (rs != null) rs.close(); }
    // maximum field size
    public int getMaxFieldSize() throws SQLException { return maxFieldSize; }
    public void setMaxFieldSize(int max) throws SQLException {
     	maxFieldSize = max;
    }
    // maximum number of rows
    public int getMaxRows() throws SQLException { return maxRows; }
    public void setMaxRows(int max) throws SQLException { maxRows = max; }
    // not supported
    public void setEscapeProcessing(boolean enable) throws SQLException {
	    throw new SQLException("TextStatement: escape processing is not supported");
    }
    // not supported
    public int getQueryTimeout() throws SQLException { return 0; }
    public void setQueryTimeout(int seconds) throws SQLException {}
    // how to cancel?
    public void cancel() throws SQLException {}
    // no warnings supported
    public SQLWarning getWarnings() throws SQLException { return null; }
    public void clearWarnings() throws SQLException {}
    // not supported
    public void setCursorName(String name) throws SQLException {}
    // only FETCH_FORWARD is supported
    public void setFetchDirection(int direction) throws SQLException {}
    public int getFetchDirection() throws SQLException {
	    return fetchDirection;
    }
    // always fetch all rows
    public void setFetchSize(int rows) throws SQLException {}
    public int getFetchSize() throws SQLException { return fetchSize; }

    /** return concurrency of generated result sets */
    public int getResultSetConcurrency() throws SQLException { return concurrency;}
    /** return type of generated result sets */
    public int getResultSetType() throws SQLException {return type;}
    // batches are not supported
    public void addBatch(String sql) throws SQLException {}
    public void clearBatch() throws SQLException {}
    public int[] executeBatch() throws SQLException { return null; }
    /** return connection */
    public Connection getConnection() throws SQLException {return con;}

    public String toString() { return getClass()+"[result="+rs+",con="+con+"]"; }

    public int getResultSetHoldability() {
      return 0;
    }
    public int executeUpdate(String sql, String[] colNam) {return 0;}
    public int executeUpdate(String sql, int[] colNam) {return 0;}
    public int executeUpdate(String sql, int colNam) {return 0;}
    public boolean execute(String sql, String[] colNam) {return false;}
    public boolean execute(String sql, int[] colNam) {return false;}
    public boolean execute(String sql, int colNam) {return false;}
    public ResultSet getGeneratedKeys() {return null;}
    public boolean getMoreResults(int x) {return false;}
}